import * as React from "react";
import TextInput from "react-native-simple-elements/components/TextInput";
import HelperText from "react-native-simple-elements/components/HelperText";

type Props = {
    label?: string,
    value: string;
    onChange: (text) => void;
    errorMessage?: string;
    secureTextEntry?: boolean;
    [key: string]: any;
};

const ValidationTextInput = (props: Props) => {
    const {
        label,
        value,
        onChange,
        errorMessage,
        secureTextEntry,
        ...rest
    } = props;

    return (
        <>
            <TextInput
                label={label}
                value={value}
                onChangeText={onChange}
                secureTextEntry={secureTextEntry}
                {...rest}
            />
            <HelperText type="error" visible={!!errorMessage}>
                {errorMessage}
            </HelperText>
        </>
    );
};

ValidationTextInput.defaultProps = {
    secureTextEntry: false,
};

export default ValidationTextInput;
